/* Copyright 2014 Marcus Wichelmann
*
* This file is part of evnc.
*
* evnc is free software: you can redistribute it
* and/or modify it under the terms of the GNU General Public License as
* published by the Free Software Foundation, either version 3 of the
* License, or (at your option) any later version.
*
* evnc is distributed in the hope that it will be
* useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
* Public License for more details.
*
* You should have received a copy of the GNU General Public License along
* with evnc. If not, see http://www.gnu.org/licenses/.
*/

namespace evnc.Dialogs {
	public class ConnectDialog : Gtk.Dialog {
		private Gtk.Box box;

		private Gtk.Grid grid_input;

		private Gtk.Label label_host;
		public Gtk.Entry entry_host;

		private Gtk.Label label_port;
		public Gtk.Entry entry_port;

		private Gtk.Label label_user;
		public Gtk.Entry entry_user;

		public Gtk.CheckButton btn_bookmark;
		public Gtk.Entry entry_bookmark;

		private Gtk.Button btn_connect;

		public ConnectDialog () {
			this.title = _("Connection set-up");
			this.resizable = false;
			this.set_modal (true);

			setup_ui ();

			connect_events ();

			this.show_all ();
		}

		private void setup_ui () {
			box = this.get_content_area () as Gtk.Box;

			grid_input = new Gtk.Grid ();
			grid_input.margin = 12;
			grid_input.column_spacing = 12;

			label_host = new Gtk.Label (_("Hostname:"));
			label_port = new Gtk.Label (_("Port:"));
			label_user = new Gtk.Label (_("Username:"));

			label_host.hexpand = true;
			label_port.hexpand = true;
			label_user.hexpand = true;
			label_host.halign = Gtk.Align.END;
			label_port.halign = Gtk.Align.END;
			label_user.halign = Gtk.Align.END;

			grid_input.attach (label_host, 0, 0, 1, 1);
			grid_input.attach (label_port, 0, 1, 1, 1);
			grid_input.attach (label_user, 0, 2, 1, 1);

			entry_host = new Gtk.Entry ();
			entry_port = new Gtk.Entry ();
			entry_user = new Gtk.Entry ();

			entry_host.set_hexpand (true);
			entry_port.set_hexpand (true);
			entry_user.set_hexpand (true);

			entry_host.set_placeholder_text (_("e.g.: joe-pc"));
			entry_port.set_placeholder_text (_("e.g.: 5900"));
			entry_user.set_placeholder_text (_("e.g.: joe"));

			entry_port.set_text ("5900");

			grid_input.attach (entry_host, 1, 0, 1, 1);
			grid_input.attach (entry_port, 1, 1, 1, 1);
			grid_input.attach (entry_user, 1, 2, 1, 1);

			btn_bookmark = new Gtk.CheckButton.with_label (_("New Bookmark:"));
			btn_bookmark.set_margin_top (6);
			entry_bookmark = new Gtk.Entry ();
			entry_bookmark.set_margin_top (6);
			entry_bookmark.set_hexpand (true);
			entry_bookmark.sensitive = false;
			entry_bookmark.set_placeholder_text (_("optional"));

			grid_input.attach (btn_bookmark, 0, 3, 1, 1);
			grid_input.attach (entry_bookmark, 1, 3, 1, 1);
			grid_input.row_spacing = 12;

			box.pack_start (grid_input);

			this.add_button (_("Cancel"), Gtk.ResponseType.CLOSE);

			btn_connect = this.add_button (_("Connect"), Gtk.ResponseType.APPLY) as Gtk.Button;
			btn_connect.get_style_context ().add_class ("suggested-action");
		}

		private void connect_events () {
			btn_bookmark.toggled.connect (() => {
				if (btn_bookmark.active) {
					btn_connect.label = _("Save and connect");
					entry_bookmark.sensitive = true;
				} else {
					btn_connect.label = _("Connect");
					entry_bookmark.sensitive = false;
				}
			});
		}
	}
}