/* Copyright 2014 Marcus Wichelmann
*
* This file is part of evnc.
*
* evnc is free software: you can redistribute it
* and/or modify it under the terms of the GNU General Public License as
* published by the Free Software Foundation, either version 3 of the
* License, or (at your option) any later version.
*
* evnc is distributed in the hope that it will be
* useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
* Public License for more details.
*
* You should have received a copy of the GNU General Public License along
* with evnc. If not, see http://www.gnu.org/licenses/.
*/

namespace evnc.Dialogs {
	public class PreferencesDialog : Gtk.Dialog {
		private SettingsManager options;

		private Gtk.Box box;

		private Gtk.Grid main_grid;

		private Gtk.Switch switch_save_new_servers;
		private Gtk.Switch switch_pointer_local;
		private Gtk.Switch switch_use_dark_theme;
		private Gtk.Switch switch_lossy_encoding;
		private Gtk.ComboBoxText combo_color_depth;

		public PreferencesDialog () {
			options = new SettingsManager ();

			this.title = _("Preferences");
			this.border_width = 5;
			this.resizable = false;
			this.set_modal (true);

			setup_ui ();

			connect_events ();

			options.settings.bind("save-new-servers", switch_save_new_servers, "active", SettingsBindFlags.DEFAULT);
			options.settings.bind("pointer-local", switch_pointer_local, "active", SettingsBindFlags.DEFAULT);
			options.settings.bind("use-dark-theme", switch_use_dark_theme, "active", SettingsBindFlags.DEFAULT);
			options.settings.bind("lossy-encoding", switch_lossy_encoding, "active", SettingsBindFlags.DEFAULT);

			var new_value = 0;
			switch (options.color_depth) {
				case "default":
					new_value = 0;
					break;
				case "full":
					new_value = 1;
					break;
				case "medium":
					new_value = 2;
					break;
				case "low":
					new_value = 3;
					break;
				case "ultra low":
					new_value = 4;
					break;
			}
			combo_color_depth.set_active (new_value);

			this.show_all ();
		}

		private void setup_ui () {
			box = this.get_content_area () as Gtk.Box;

			main_grid = new Gtk.Grid ();
			main_grid.margin = 12;
			main_grid.column_spacing = 12;
			main_grid.row_spacing = 12;

			main_grid.attach (new AlignLabel (_("Save new servers:")), 0, 0, 1, 1);
			switch_save_new_servers = new Gtk.Switch ();
			switch_save_new_servers.halign = Gtk.Align.START;
			main_grid.attach (switch_save_new_servers, 1, 0, 1, 1);

			main_grid.attach (new AlignLabel (_("Use the local pointer:")), 0, 1, 1, 1);
			switch_pointer_local = new Gtk.Switch ();
			switch_pointer_local.halign = Gtk.Align.START;
			main_grid.attach (switch_pointer_local, 1, 1, 1, 1);

			main_grid.attach (new AlignLabel (_("Use the dark theme:")), 0, 2, 1, 1);
			switch_use_dark_theme = new Gtk.Switch ();
			switch_use_dark_theme.halign = Gtk.Align.START;
			main_grid.attach (switch_use_dark_theme, 1, 2, 1, 1);

			main_grid.attach (new AlignLabel (_("Use the lossy encoding:")), 0, 3, 1, 1);
			switch_lossy_encoding = new Gtk.Switch ();
			switch_lossy_encoding.halign = Gtk.Align.START;
			main_grid.attach (switch_lossy_encoding, 1, 3, 1, 1);

			main_grid.attach (new AlignLabel (_("Color depth:")), 0, 4, 1, 1);
			combo_color_depth = new Gtk.ComboBoxText ();
			combo_color_depth.append_text (_("Server configuration"));
			combo_color_depth.append_text (_("True quality (24bit)"));
			combo_color_depth.append_text (_("High quality (16bit)"));
			combo_color_depth.append_text (_("Low quality (8bit)"));
			combo_color_depth.append_text (_("Ultra low quality (3bit)"));
			main_grid.attach (combo_color_depth, 1, 4, 1, 1);

			box.pack_start (main_grid);

			this.add_button (_("Close"), Gtk.ResponseType.CLOSE);
		}

		private void connect_events () {
			combo_color_depth.changed.connect (() => {
				var new_value = "default";
				switch (combo_color_depth.get_active ()) {
					case 0:
						new_value = "default";
						break;
					case 1:
						new_value = "full";
						break;
					case 2:
						new_value = "medium";
						break;
					case 3:
						new_value = "low";
						break;
					case 4:
						new_value = "ultra low";
						break;
				}
				options.color_depth = new_value;
			});
		}
	}

	public class AlignLabel : Gtk.Label
	{
		public AlignLabel (string text) {
			this.hexpand = true;
			this.halign = Gtk.Align.END;
			this.label = text;
		}
	}
}