/* Copyright 2014 Marcus Wichelmann
*
* This file is part of evnc.
*
* evnc is free software: you can redistribute it
* and/or modify it under the terms of the GNU General Public License as
* published by the Free Software Foundation, either version 3 of the
* License, or (at your option) any later version.
*
* evnc is distributed in the hope that it will be
* useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
* Public License for more details.
*
* You should have received a copy of the GNU General Public License along
* with evnc. If not, see http://www.gnu.org/licenses/.
*/

namespace evnc {
	public class MainWindow : Gtk.Window {
		// App
		public evncApp app;

		// Settings
		private SettingsManager options;

		// Container
		private Gtk.Box box;
		private Widgets.TitleBar titlebar;
		private Widgets.Information information;
		private Widgets.MainView mainview;

		public MainWindow (evncApp app) {
			this.app = app;
			this.set_application (app);

			options = new SettingsManager ();

			// Change the theme
			Gtk.Settings.get_default ().gtk_application_prefer_dark_theme = options.use_dark_theme;
			options.on_use_dark_theme_changed.connect ((val) => {
				Gtk.Settings.get_default ().gtk_application_prefer_dark_theme = val;
			});

			// Window propterties
			this.set_size_request (900, 650);
			this.set_has_resize_grip (false);
			this.window_position = Gtk.WindowPosition.CENTER;

			// Draw UI
			setup_ui ();
			this.show_all ();
		}

		private void setup_ui () {
			box = new Gtk.Box (Gtk.Orientation.VERTICAL, 0);

			titlebar = new Widgets.TitleBar (this);

			this.set_titlebar (titlebar);
			box.pack_start (titlebar, false, true);

			information = new Widgets.Information ();
			box.pack_start (information, false, true);

			mainview = new Widgets.MainView ();
			box.pack_start (mainview, true, true);

			this.add (box);

			titlebar.on_connect_request.connect (mainview.notebook.add_connection);
			titlebar.on_take_screenshot_clicked.connect (() => {
				(mainview.notebook.current as Widgets.VncConnection).take_screenshot ();
			});

			mainview.on_show_connect_dialog_request.connect (titlebar.show_connect_dialog);
			mainview.on_open_bookmarks_request.connect (() => {
				titlebar.bookmarksmenu.popup (null, null, null, 0, Gtk.get_current_event_time ());
			});
			mainview.notebook.on_connection_message.connect (information.show_text);
			mainview.notebook.tab_added.connect (() => {
				titlebar.btn_screenshot.set_sensitive (true);
			});
			mainview.notebook.tab_removed.connect (() => {
				if (mainview.notebook.n_tabs == 0) {
					titlebar.btn_screenshot.set_sensitive (false);
				}
			});
		}
	}
}