namespace evnc {
	public class SettingsManager : Object {
		// Path
		static const string SETTINGS_PATH = "org.pantheon.evnc";

		// Keys
		static const string BOOKMARK_LIST_KEY = "bookmark-list";
		static const string SAVE_NEW_SERVERS_KEY = "save-new-servers";
		static const string POINTER_LOCAL_KEY = "pointer-local";
		static const string USE_DARK_THEME_KEY = "use-dark-theme";
		static const string DISPLAY_MODE_KEY = "display-mode";
		static const string READONLY_KEY = "readonly";
		static const string LOSSY_ENCODING_KEY = "lossy-encoding";
		static const string COLOR_DEPTH_KEY = "color-depth";

		// Fields
		public string[] bookmark_list { get; set; }
		public bool save_new_servers { get; set; default = false; }
		public bool pointer_local { get; set; default = true; }
		public bool use_dark_theme { get; set; default = false; }
		public int display_mode { get; set; default = 0; }
		public bool readonly { get; set; default = false; }
		public bool lossy_encoding { get; set; default = false; }
		public string color_depth { get; set; default = "default"; }

		// Events
		public signal void on_pointer_local_changed (bool new_value);
		public signal void on_use_dark_theme_changed (bool new_value);
		public signal void on_display_mode_changed (int new_value);

		// Settings object
		public Settings? settings = null;

		public SettingsManager () {
			// Connect
			this.settings = new Settings (SETTINGS_PATH);


			this.settings.bind (BOOKMARK_LIST_KEY, this, "bookmark-list", SettingsBindFlags.DEFAULT);
			this.settings.bind (SAVE_NEW_SERVERS_KEY, this, "save-new-servers", SettingsBindFlags.DEFAULT);
			this.settings.bind (POINTER_LOCAL_KEY, this, "pointer-local", SettingsBindFlags.DEFAULT);
			this.settings.bind (USE_DARK_THEME_KEY, this, "use-dark-theme", SettingsBindFlags.DEFAULT);
			this.settings.bind (DISPLAY_MODE_KEY, this, "display-mode", SettingsBindFlags.DEFAULT);
			this.settings.bind (READONLY_KEY, this, "readonly", SettingsBindFlags.DEFAULT);
			this.settings.bind (LOSSY_ENCODING_KEY, this, "lossy-encoding", SettingsBindFlags.DEFAULT);
			this.settings.bind (COLOR_DEPTH_KEY, this, "color-depth", SettingsBindFlags.DEFAULT);

			// Connect events
			this.settings.changed[POINTER_LOCAL_KEY].connect (() => {
				this.on_pointer_local_changed (pointer_local);
			});
			this.settings.changed[USE_DARK_THEME_KEY].connect (() => {
				this.on_use_dark_theme_changed (use_dark_theme);
			});
			this.settings.changed[DISPLAY_MODE_KEY].connect (() => {
				this.on_display_mode_changed (display_mode);
			});
		}
	}
}