/* Copyright 2014 Marcus Wichelmann
*
* This file is part of evnc.
*
* evnc is free software: you can redistribute it
* and/or modify it under the terms of the GNU General Public License as
* published by the Free Software Foundation, either version 3 of the
* License, or (at your option) any later version.
*
* evnc is distributed in the hope that it will be
* useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
* Public License for more details.
*
* You should have received a copy of the GNU General Public License along
* with evnc. If not, see http://www.gnu.org/licenses/.
*/

namespace evnc.Widgets {
	public class BookmarksMenu : Gtk.Menu {
		public signal void on_bookmark_selected (string host, string port, string user);
		public signal void on_new_bookmark_clicked ();

		private SettingsManager options;

		public BookmarksMenu () {
			options = new SettingsManager ();

			update_menu ();
		}

		private void update_menu () {
			foreach (Gtk.Widget item in this.get_children ()) {
				this.remove(item);
			}

			for (int i = 0; i < options.bookmark_list.length; i++) {
				var parameters = options.bookmark_list[i].split ("|");

				// Parameteranzahl korrekt?
				if (parameters.length >= 4) {
					var item = new Gtk.MenuItem.with_label (parameters[0]);
					var item_sub_menu = new Gtk.Menu ();
					var item_open = new Gtk.MenuItem.with_label (_("Connect"));
					var item_remove = new Gtk.MenuItem.with_label (_("Remove"));

					// FIXME: I need the current iterator for the signals.
					var index = i;

					item_open.activate.connect (() => {
						on_bookmark_selected (parameters[1], parameters[2], parameters[3]);
					});

					item_remove.activate.connect (() => {
						var bookmarks_new = new string[options.bookmark_list.length - 1];
						var count = 0;

						for (int b = 0; b < options.bookmark_list.length; b++) {
							if (b != index) {
								bookmarks_new[count] = options.bookmark_list[b];
								count++;
							}
						}

						options.bookmark_list = bookmarks_new;
						update_menu ();
					});

					item_sub_menu.add (item_open);
					item_sub_menu.add (item_remove);

					item.submenu = item_sub_menu;

					this.add (item);
				}
			}

			if (options.bookmark_list.length > 0) {
				this.add (new Gtk.SeparatorMenuItem ());
			}

			var create_item = new Gtk.MenuItem.with_label (_("Add new bookmark"));
			create_item.activate.connect (() => {
				on_new_bookmark_clicked ();
			});

			this.add (create_item);
			this.show_all ();
		}

		public void add_bookmark (string new_bookmark) {
			var bookmarks_new = new string[options.bookmark_list.length + 1];
			var count = 1;

			bookmarks_new[0] = new_bookmark;

			for (int i = 0; i < options.bookmark_list.length; i++) {
				bookmarks_new[count] = options.bookmark_list[i];
				count++;
			}

			options.bookmark_list = bookmarks_new;

			update_menu ();
		}
	}
}