/* Copyright 2014 Marcus Wichelmann
*
* This file is part of evnc.
*
* evnc is free software: you can redistribute it
* and/or modify it under the terms of the GNU General Public License as
* published by the Free Software Foundation, either version 3 of the
* License, or (at your option) any later version.
*
* evnc is distributed in the hope that it will be
* useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
* Public License for more details.
*
* You should have received a copy of the GNU General Public License along
* with evnc. If not, see http://www.gnu.org/licenses/.
*/

namespace evnc.Widgets {
	public class MainView : Gtk.Stack {
		public signal void on_show_connect_dialog_request (bool save_as_bookmark);
		public signal void on_open_bookmarks_request ();

		private SettingsManager options;

		private Granite.Widgets.Welcome welcome;

		public Widgets.Notebook notebook;

		public MainView () {
			options = new SettingsManager ();

			welcome = new Granite.Widgets.Welcome (_("Connect to a VNC-Server"), _("Create a new connection or choose one of your bookmarks."));
			welcome.append ("add", _("New Connection"), _("Enter hostname, port and your credentials."));
			welcome.append ("help-about", _("Open Bookmarks"), _("Choose a server from your bookmarks."));
			welcome.activated.connect ((index) => {
				if (index == 0) {
					on_show_connect_dialog_request (options.save_new_servers);
				} else if (index == 1) {
					on_open_bookmarks_request ();
				}
			});

			this.add_named (welcome, "welcome");

			notebook = new Widgets.Notebook ();
			notebook.tab_added.connect (() => {
				this.transition_duration = 1200;
				this.transition_type = Gtk.StackTransitionType.OVER_LEFT;
				this.set_visible_child_name ("notebook");
			});
			notebook.tab_removed.connect (() => {
				if (notebook.n_tabs == 0) {
					this.transition_duration = 400;
					this.transition_type = Gtk.StackTransitionType.CROSSFADE;
					this.set_visible_child_name ("welcome");
				}
			});
			notebook.new_tab_requested.connect (() => {
				on_show_connect_dialog_request (options.save_new_servers);
			});

			this.add_named (notebook, "notebook");
			this.show_all ();
			this.set_visible_child_name ("welcome");
		}
	}
}