/* Copyright 2014 Marcus Wichelmann
*
* This file is part of evnc.
*
* evnc is free software: you can redistribute it
* and/or modify it under the terms of the GNU General Public License as
* published by the Free Software Foundation, either version 3 of the
* License, or (at your option) any later version.
*
* evnc is distributed in the hope that it will be
* useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
* Public License for more details.
*
* You should have received a copy of the GNU General Public License along
* with evnc. If not, see http://www.gnu.org/licenses/.
*/

namespace evnc.Widgets {
	public class TitleBar : Gtk.HeaderBar {
		public signal void on_take_screenshot_clicked ();
		public signal void on_connect_request (string host, string port, string user);

		private SettingsManager options;

		private Granite.Widgets.ModeButton display_mode;

		public Gtk.ToolButton btn_screenshot;

		private Gtk.ToggleToolButton btn_readonly;

		private Gtk.MenuToolButton btn_connect;
		public Widgets.BookmarksMenu bookmarksmenu;

		private Gtk.Menu main_menu;
		private Gtk.MenuItem preferences_item;
		private Granite.Widgets.AppMenu app_menu;

		public TitleBar (MainWindow parent) {
			options = new SettingsManager ();

			this.get_style_context ().add_class ("primary-toolbar");
			this.show_close_button = true;
			this.set_title (_("VNC-Client"));

			display_mode = new Granite.Widgets.ModeButton ();
			display_mode.set_margin_top (4);
			display_mode.set_margin_bottom (4);
			display_mode.append_icon ("zoom-fit-best-symbolic", Gtk.IconSize.BUTTON);
			display_mode.append_icon ("zoom-original-symbolic", Gtk.IconSize.BUTTON);
			// FIXME: Using settings.bind only, won't work if you click on the buttons.
			display_mode.mode_changed.connect (() =>{
				options.display_mode = display_mode.selected;
			});
			options.settings.bind("display-mode", display_mode, "selected", SettingsBindFlags.DEFAULT);


			this.pack_start (display_mode);

			btn_screenshot = new Gtk.ToolButton (new Gtk.Image.from_icon_name ("camera-photo", Gtk.IconSize.SMALL_TOOLBAR), null);
			btn_screenshot.set_tooltip_text (_("Take Screenshot"));
			btn_screenshot.set_sensitive (false);
			btn_screenshot.clicked.connect (() => {
				on_take_screenshot_clicked ();
			});

			this.pack_start (btn_screenshot);

			btn_readonly = new Gtk.ToggleToolButton ();
			btn_readonly.set_icon_name("locked");
			btn_readonly.set_tooltip_text (_("Input Lock"));
			options.settings.bind("readonly", btn_readonly, "active", SettingsBindFlags.DEFAULT);

			this.pack_start (btn_readonly);

			preferences_item = new Gtk.MenuItem.with_label (_("Preferences"));
			preferences_item.activate.connect (() => {
				var dialog = new Dialogs.PreferencesDialog ();
				dialog.response.connect ((source, response_id) => {
					dialog.destroy ();
				});
			});

			main_menu = new Gtk.Menu ();
			main_menu.add (preferences_item);

			app_menu = parent.app.create_appmenu (main_menu);

			this.pack_end (app_menu);

			btn_connect = new Gtk.MenuToolButton (new Gtk.Image.from_icon_name ("user-bookmarks", Gtk.IconSize.SMALL_TOOLBAR), null);
			btn_connect.set_tooltip_text (_("Server list"));
			btn_connect.clicked.connect (() => {
				show_connect_dialog (options.save_new_servers);
			});

			this.pack_end (btn_connect);

			bookmarksmenu = new Widgets.BookmarksMenu ();
			bookmarksmenu.on_bookmark_selected.connect ((host, port, user) => {
				on_connect_request (host, port, user);
			});
			bookmarksmenu.on_new_bookmark_clicked.connect (() => {
				show_connect_dialog (true);
			});
			btn_connect.set_menu (bookmarksmenu);
		}

		public void show_connect_dialog (bool save_as_bookmark) {
			var dialog = new Dialogs.ConnectDialog ();
			dialog.btn_bookmark.set_active (save_as_bookmark);
			dialog.response.connect ((source, response_id) => {
				switch (response_id) {
					case Gtk.ResponseType.CLOSE:
						dialog.destroy ();
						break;
					case Gtk.ResponseType.APPLY:
						on_connect_request (dialog.entry_host.text, dialog.entry_port.text, dialog.entry_user.text);

						if (dialog.btn_bookmark.active) {
							var new_bookmark = "";

							if (dialog.entry_bookmark.text == "") {
								if (dialog.entry_user.text != "") {
									new_bookmark += dialog.entry_user.text + "@";
								}
								new_bookmark += dialog.entry_host.text + ":" + dialog.entry_port.text;
							} else {
								new_bookmark += dialog.entry_bookmark.text.replace ("|", "/");
							}

							new_bookmark += "|" + dialog.entry_host.text + "|" + dialog.entry_port.text + "|" + dialog.entry_user.text;
							bookmarksmenu.add_bookmark (new_bookmark);
						}

						dialog.destroy ();
						break;
				}
			});
		}
	}
}