/* Copyright 2014 Marcus Wichelmann
*
* This file is part of evnc.
*
* evnc is free software: you can redistribute it
* and/or modify it under the terms of the GNU General Public License as
* published by the Free Software Foundation, either version 3 of the
* License, or (at your option) any later version.
*
* evnc is distributed in the hope that it will be
* useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
* Public License for more details.
*
* You should have received a copy of the GNU General Public License along
* with evnc. If not, see http://www.gnu.org/licenses/.
*/

namespace evnc {
	public class evncApp : Granite.Application {
		public MainWindow window;

		construct {
			// App-Properties
			program_name = "VNC-Client";
			exec_name = "evnc";

			build_data_dir = Constants.DATADIR;
			build_pkg_data_dir = Constants.PKGDATADIR;
			build_release_name = Constants.RELEASE_NAME;
			build_version = Constants.VERSION;
			build_version_info = Constants.VERSION_INFO;

			app_years = "2014";
			app_icon = "evnc";
			app_launcher = "evnc.desktop";
			application_id = "net.launchpad.evnc";
			main_url = "https://code.launchpad.net/evnc";
			bug_url = "https://bugs.launchpad.net/evnc";
			help_url = "https://code.launchpad.net/evnc";
			translate_url = "https://translations.launchpad.net/evnc";
			about_authors = { "Marcus Wichelmann <admin@marcusw.de>" };
			about_documenters = { "Marcus Wichelmann <admin@marcusw.de>" };
			about_artists = { "Marcus Wichelmann <admin@marcusw.de>" };
			about_comments = "A VNC-Viewer for elementary OS";
			about_translators = "Launchpad Translators";
		}

		public evncApp () {
			// Translations
			Intl.setlocale (LocaleCategory.ALL, "");
			string langpack_dir = Path.build_filename (Constants.INSTALL_PREFIX, "share", "locale");
			Intl.bindtextdomain (Constants.GETTEXT_PACKAGE, langpack_dir);
			Intl.bind_textdomain_codeset (Constants.GETTEXT_PACKAGE, "UTF-8");
			Intl.textdomain (Constants.GETTEXT_PACKAGE);

			// Debug service
			Granite.Services.Logger.initialize ("evnc");
			Granite.Services.Logger.DisplayLevel = Granite.Services.LogLevel.DEBUG;

			//Vnc.util_set_debug (true);
			//Granite.Services.Logger.notification (Vnc.util_get_version_string ());
		}

		public override void activate () {
			if (get_windows () == null) {
				window = new MainWindow (this);
				window.show_all ();
			} else {
				window.present ();
			}
		}

		public override void open (File [] files, string hint) {
			// Do nothing
		}

		public static void main (string [] args) {
			// Instantiate and run
			var app = new evnc.evncApp ();
			app.run (args);
		}
	}
}